Chapter 1: Strong Lensing
=========================

In chapter 1, we introduce you to strong gravitational lensing and the core **PyAutoLens** API.

**Binder** links to every tutorial are included.

The chapter contains the following tutorials:

`Tutorial 0: Visualization <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_0_visualization.ipynb>`_
- Setting up **PyAutoLens**'s visualization library.

`Tutorial 1: Grids And Galaxies <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_1_grids_and_galaxies.ipynb>`_
- Using grids of (y,x) coordinates with galaxies made up of light profiles.

`Tutorial 2: Ray Tracing <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_2_ray_tracing.ipynb>`_
- Using grids, galaxies and mass profiles to perform strong lens ray-tracing.

`Tutorial 3: More Ray Tracing <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_3_more_ray_tracing.ipynb>`_
- Advanced strong lens ray-tracing.

`Tutorial 4: Point Sources <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_4_point_sources.ipynb>`_
- How lensing calculations when the source galaxy is a point-source (e.g. a quasar).

`Tutorial 5: Lensing Formalism <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_5_lensing_formalism.ipynb>`_
- The algebraic lensing formalism used to describe strong lensing.

`Tutorial 6: Data <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_6_data.ipynb>`_
- Loading and inspecting telescope imaging data of a strong lens.

`Tutorial 7: Fitting <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_7_fitting.ipynb>`_
- Fitting data with a strong lens model.

`Tutorial 8: Summary <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_8_summary.ipynb>`_
- A summary of the chapter.